Learn R Programming

perccal (version 1.0)

perccal-package: Computing Confidence Intervals Via Double Bootstrap 'perc-cal' Method

Description

Contains functions which allow the user to compute confidence intervals quickly using the double bootstrap-based percentile calibrated ('perc-cal') method for linear regression coefficients.

Arguments

Details

Package:
perccal
Type:
Package
Version:
1.0
Date:
2016-06-14
License:
GPL-3

Contains functions which allow users to compute confidence intervals quickly using the double bootstrap-based percentile calibrated ('perc-cal') method for linear regression coefficients. The help of Justin Bleich is strongly acknowledged.

References

Efron, Bradley; Tibshirani, Robert J. “An Introduction to the Bootstrap” 1994. Book. Publisher: CRC Press.

McCarthy, Daniel; Zhang, Kai; Berk, Richard; Brown, Lawrence; Buja, Andreas; George, Edward; Zhao, Linda. “Calibrated Percentile Double Bootstrap For Robust Linear Regression Inference” 2016. Available on arXiv: https://arxiv.org/abs/1511.00273